#include <algorithm>
#include <array>
#include <cassert>
#include <cstdint>
#include <iostream>
#include <string>
#include <string_view>
#include <utility>
#include <vector>

// Slower solution using Karatsuba

struct ModInt {
    static constexpr int32_t MOD = 998'244'353;

    static int32_t modPow(int32_t base, int32_t exp) {
        int32_t res = 1;
        while (exp) {
            if (exp & 1) {
                res = (1LL * res * base) % MOD;
            }
            base = 1LL * base * base % MOD;
            exp >>= 1;
        }

        return res;
    }

    int32_t v_;

    ModInt(int32_t v = 0): v_(v) {}

    ModInt& operator+=(ModInt rhs) {
        v_ += rhs.v_;
        if (v_ >= MOD) v_ -= MOD;

        return *this;
    }

    ModInt& operator-=(ModInt rhs) {
        v_ -= rhs.v_;
        if (v_ < 0) v_ += MOD;

        return *this;
    }

    ModInt& operator*=(ModInt rhs) {
        v_ = 1LL * v_ * rhs.v_ % MOD;

        return *this;
    }

    friend ModInt operator+(ModInt lhs, ModInt rhs) {
        int32_t v = lhs.v_ + rhs.v_;
        if (v >= MOD) v -= MOD;

        return ModInt{v};
    }

    friend ModInt operator-(ModInt lhs, ModInt rhs) {
        int32_t v = lhs.v_ - rhs.v_;
        if (v < 0) v += MOD;
        return ModInt{v};
    }

    friend ModInt operator*(ModInt lhs, ModInt rhs) {
        int32_t v = 1LL * lhs.v_ * rhs.v_ % MOD;
        return ModInt{v};
    }
};

struct Poly {
    std::vector<ModInt> coeffs_;

    Poly(std::vector<ModInt>&& c = {}): coeffs_(c) {}

    size_t size() const {
        return coeffs_.size();
    }

    Poly& operator+=(const Poly& rhs) {
        if (rhs.size() > size()) {
            coeffs_.resize(rhs.size(), ModInt{});
        }

        for (size_t i = 0; i < rhs.size(); ++i) {
            coeffs_[i] += rhs.coeffs_[i];
        }

        return *this;
    }

    Poly& operator-=(const Poly& rhs) {
        if (rhs.size() > size()) {
            coeffs_.resize(rhs.size());
        }

        for (size_t i = 0; i < rhs.size(); ++i) {
            coeffs_[i] -= rhs.coeffs_[i];
        }

        return *this;
    }

    Poly operator+(const Poly& rhs) const {
        Poly p = *this;
        p += rhs;
        return p;
    }

    Poly operator-(const Poly& rhs) const {
        Poly p = *this;
        p -= rhs;
        return p;
    }

    Poly operator*(const Poly& rhs) const {
        if (coeffs_.empty() || rhs.coeffs_.empty()) {
            return Poly{};
        }

        static constexpr size_t BOUND = 100 * 100;
        if (size() * rhs.size() < BOUND) {
            return slowMul(*this, rhs);
        } else {
            return karatsuba(*this, rhs);
        }
    }

    friend Poly slowMul(const Poly& lhs, const Poly& rhs) {
        size_t resSize = lhs.size() + rhs.size() - 1;
        std::vector<ModInt> c(resSize, ModInt{});
        for (int32_t i = 0; i < lhs.size(); ++i) {
            for (int32_t j = 0; j < rhs.size(); ++j) {
                c[i + j] += lhs.coeffs_[i] * rhs.coeffs_[j];
            }
        }

        return Poly{std::move(c)};
    }

    std::array<Poly, 2> split(int32_t h) const {
        if (h < size()) {
            std::vector<ModInt> lo{coeffs_.begin(), coeffs_.begin() + h};
            std::vector<ModInt> hi{coeffs_.begin() + h, coeffs_.end()};
            return {Poly{std::move(lo)}, Poly{std::move(hi)}};
        } else {
            return {*this, Poly{}};
        }
    }

    friend Poly karatsuba(const Poly& lhs, const Poly& rhs) {
        int32_t h = std::max(lhs.size(), rhs.size()) / 2;
        auto [x0, x1] = lhs.split(h);
        auto [y0, y1] = rhs.split(h);

        Poly z3 = (x1 + x0) * (y1 + y0);
        Poly z2 = x1 * y1;
        Poly z0 = x0 * y0;
        Poly z1 = z3 - z2 - z0;

        size_t resSize = lhs.size() + rhs.size() - 1;
        std::vector<ModInt> c(resSize, 0);
        for (int32_t i = 0; i < z2.size(); ++i) {
            c[i + h + h] += z2.coeffs_[i];
        }

        for (int32_t i = 0; i < z1.size(); ++i) {
            c[i + h] += z1.coeffs_[i];
        }

        for (int32_t i = 0; i < z0.size(); ++i) {
            c[i] += z0.coeffs_[i];
        }

        return Poly{std::move(c)};
    }

    friend std::ostream& operator<<(std::ostream& os, const Poly& p) {
        bool first = true;
        os << "Poly(";
        for (ModInt c : p.coeffs_) {
            if (!first)
                os << ", ";
            os << c.v_;
        }
        return os << ")";
    }
};

using Block = std::array<std::array<Poly, 3>, 3>;

Block solve(std::string_view s) {
    Block res{};
    if (s.size() == 1) {
        if (s[0] == 'B') {
            res[0][0] = Poly{{0, 1}};
        } else if (s[0] == 'Y') {
            res[1][1] = Poly{{0, 1}};
        } else if (s[0] == 'R') {
            res[2][2] = Poly{{0, 1}};
        } else {
            assert(false);
        }
    } else {
        size_t h = s.size() / 2;
        Block lhs = solve(s.substr(0, h));
        Block rhs = solve(s.substr(h));
        for (int32_t i = 0; i < 3; ++i) {
            for (int32_t j = i; j < 3; ++j) {
                res[i][j] += lhs[i][j];
                res[i][j] += rhs[i][j];
                for (int32_t k = j; k < 3; ++k) {
                    for (int32_t l = k; l < 3; ++l) {
                        res[i][l] += lhs[i][j] * rhs[k][l];
                    }
                }
            }
        }
    }

    return res;
}

int main() {
    std::string s;
    std::cin >> s;

    Block res = solve(s);

    Poly final{};
    for (int32_t i = 0; i < 3; ++i) {
        for (int32_t j = i; j < 3; ++j) {
            final += res[i][j];
        }
    }

    int32_t n = s.size();
    std::vector<ModInt> probs(n + 1, ModInt{});
    ModInt invChoose = 1;
    for (int32_t i = n; i > 0; --i) {
        ModInt c = i < final.coeffs_.size() ? final.coeffs_[i] : ModInt{};

        probs[i] = c * invChoose;
        invChoose *= ModInt::modPow(i, ModInt::MOD - 2);
        invChoose *= n - i + 1;
    }
    
    for (int32_t i = 1; i < n; ++i) {
        probs[i] -= probs[i + 1];
    }

    ModInt exp = 0;
    for (int32_t i = 1; i <= n; ++i) {
        exp += i * probs[i];
    }

    std::cout << (ModInt{n} - exp).v_ << '\n';

    return 0;
}
